SystemOrganization addCategory: #'Seaside-Tests-Cache-NG'!

TestCase subclass: #WACacheNGTest
	instanceVariableNames: 'cache'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Cache-NG'!

!WACacheNGTest methodsFor: 'running' stamp: 'pmm 9/10/2013 12:13'!
setUp
	cache := WAHashCacheNG
		initialSize: 13
		maximumSize: 0
		maximumAbsoluteAge: 0
		maximumRelativeAge: 0
		overflowAction: WAHashCacheNG signalError! !

!WACacheNGTest methodsFor: 'testing' stamp: 'pmm 9/10/2013 12:37'!
testAtPut
	1 to: 100 do: [ :i |
		| absent mapped |
		absent := false.
		cache at: i ifAbsent: [ absent := true ].
		self assert: absent.
		mapped := cache at: i put: i greaseString.
		self assert: mapped = i greaseString.
		mapped := cache at: i ifAbsent: [ self fail ].
		self assert: mapped = i greaseString ]! !

!WACacheNGTest methodsFor: 'testing' stamp: 'pmm 9/10/2013 12:41'!
testAtPutOverwrite
	1 to: 100 do: [ :i |
		| absent mapped |
		absent := false.
		cache at: i ifAbsent: [ absent := true ].
		self assert: absent.
		cache at: i put: 'zork'.
		mapped := cache at: i put: i greaseString.
		self assert: mapped = i greaseString.
		mapped := cache at: i ifAbsent: [ self fail ].
		self assert: mapped = i greaseString ]! !

!WACacheNGTest methodsFor: 'testing' stamp: 'pmm 9/10/2013 12:38'!
testKeyAtValue
	1 to: 100 do: [ :i |
		| absent key |
		absent := false.
		cache keyAtValue: i greaseString ifAbsent: [ absent := true ].
		self assert: absent.
		cache at: i put: i greaseString.
		key := cache keyAtValue: i greaseString ifAbsent: [ self fail ].
		self assert: key = i ]! !

!WACacheNGTest methodsFor: 'testing' stamp: 'pmm 9/10/2013 12:50'!
testKeysAndValuesDo
	| reference readBack |
	reference := Dictionary new.

	1 to: 100 do: [ :i |
		cache at: i put: i greaseString.
		reference at: i put: i greaseString ].
	
	readBack := Dictionary new.
	cache keysAndValuesDo: [ :key :value |
		readBack at: key put: value ].
	
	self assert: readBack = reference! !

!WACacheNGTest methodsFor: 'testing' stamp: 'pmm 9/10/2013 12:53'!
testMultipleMappings
	cache at: 'key1' put: 'value'.
	self should: [ cache at: 'key2' put: 'value' ] raise: Error! !

!WACacheNGTest methodsFor: 'testing' stamp: 'pmm 9/10/2013 13:59'!
testRemove
	1 to: 100 do: [ :i |
		cache at: i put: i greaseString ].
	
	1 to: 100 do: [ :i |
		| absent mapped |
		self assert: (cache at: i ifAbsent: [ self fail ]) = i greaseString.
		cache remove: i greaseString.
		absent := false.
		cache at: i ifAbsent: [ absent := true ].
		self assert: absent ].! !

!WACacheNGTest methodsFor: 'testing' stamp: 'pmm 9/10/2013 17:21'!
testRemoveAbsoluteOldest
	cache := WAHashCacheNG
		initialSize: 13
		maximumSize: 10
		maximumAbsoluteAge: 0
		maximumRelativeAge: 0
		overflowAction: WAHashCacheNG removeAbsoluteOldest.
		
	1 to: 20 do: [ :i |
		"i = 11 ifTrue: [ self halt ]."
		cache at: i put: i greaseString ].
	
	1 to: 10 do: [ :i |
		| absent |
		absent := false.
		cache at: i ifAbsent: [ absent := true ].
		self assert: absent ].
	
	11 to: 20 do: [ :i |
		| mapped |
		mapped := cache at: i ifAbsent: [ self fail ].
		self assert: mapped = i greaseString ].! !

Object subclass: #WACacheNGPerformanceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Cache-NG'!

!WACacheNGPerformanceTest methodsFor: 'testing' stamp: 'pmm 9/10/2013 12:12'!
testObjectStorage
	WACache new! !
